# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mlconjug3', 'tests']

package_data = \
{'': ['*'],
 'mlconjug3': ['data/conjug_manager/*',
               'data/models/*',
               'locale/es/LC_MESSAGES/*',
               'locale/fr/LC_MESSAGES/*',
               'locale/it/LC_MESSAGES/*',
               'locale/pt/LC_MESSAGES/*',
               'locale/ro/LC_MESSAGES/*']}

install_requires = \
['click==8.0.3',
 'colorama==0.4.4',
 'cython==0.29.24',
 'defusedxml==0.7.1',
 'joblib==1.1.0',
 'numpy',
 'progressbar2==3.55.0',
 'scikit-learn==1.0',
 'scipy']

entry_points = \
{'console_scripts': ['mlconjug3 = mlconjug3.cli:main']}

setup_kwargs = {
    'name': 'mlconjug3',
    'version': '3.8.1',
    'description': 'A Python library to conjugate French, English, Spanish, Italian, Portuguese and Romanian verbs using Machine Learning techniques.',
    'long_description': '.. image:: https://raw.githubusercontent.com/SekouDiaoNlp/mlconjug3/master/logo/logotype2%20mlconjug.png\n        :target: https://pypi.python.org/pypi/mlconjug3\n        :alt: mlconjug3 PyPi Home Page\n\n=========\nMLCONJUG3\n=========\n\n\n.. image:: https://img.shields.io/badge/Maintained%3F-yes-green.svg\n        :target: https://GitHub.com/SekouDiaoNlp/mlconjug3/graphs/commit-activity\n        :alt: Package Maintenance Status\n\n.. image:: https://img.shields.io/badge/maintainer-SekouDiaoNlp-blue\n        :target: https://GitHub.com/SekouDiaoNlp/mlconjug3\n        :alt: Package Maintener\n\n.. image:: https://github.com/SekouDiaoNlp/mlconjug3/workflows/mlconjug3/badge.svg\n        :target: https://github.com/SekouDiaoNlp/mlconjug3/actions\n        :alt: Build status on Windows, MacOs and Linux\n\n.. image:: https://img.shields.io/pypi/v/mlconjug3.svg\n        :target: https://pypi.python.org/pypi/mlconjug3\n        :alt: Pypi Python Package Index Status\n\n.. image:: https://anaconda.org/conda-forge/mlconjug3/badges/version.svg\n        :target: https://anaconda.org/conda-forge/mlconjug3\n        :alt: Anaconda Package Index Status\n\n.. image:: https://img.shields.io/pypi/pyversions/mlconjug3\n        :target: https://pypi.python.org/pypi/mlconjug3\n        :alt: Compatible Python versions\n\n.. image:: https://img.shields.io/conda/pn/conda-forge/mlconjug3?color=dark%20green&label=Supported%20platforms\n        :target: https://anaconda.org/conda-forge/mlconjug3\n        :alt: Supported platforms\n\n.. image:: https://readthedocs.org/projects/mlconjug3/badge/?version=latest\n        :target: https://mlconjug3.readthedocs.io/en/latest\n        :alt: Documentation Status\n\n.. image:: https://pyup.io/repos/github/SekouDiaoNlp/mlconjug3/shield.svg\n        :target: https://pyup.io/repos/github/SekouDiaoNlp/mlconjug3/\n        :alt: Dependencies status\n\n.. image:: https://codecov.io/gh/SekouDiaoNlp/mlconjug3/branch/master/graph/badge.svg\n        :target: https://codecov.io/gh/SekouDiaoNlp/mlconjug3\n        :alt: Code Coverage Status\n\n.. image:: https://snyk-widget.herokuapp.com/badge/pip/mlconjug3/badge.svg\n        :target: https://snyk.io/test/github/SekouDiaoNlp/mlconjug3?targetFile=requirements.txt\n        :alt: Code Vulnerability Status\n\n.. image:: https://img.shields.io/pypi/dm/mlconjug3?label=PyPi%20Downloads\n        :target: https://pypi.python.org/pypi/mlconjug3\n        :alt: PyPI Downloads\n\n.. image:: https://img.shields.io/conda/dn/conda-forge/mlconjug?label=Anaconda%20Total%20Downloads\n        :target: https://anaconda.org/conda-forge/mlconjug3\n        :alt: Conda\n\n\n\n\n\n| A Python library to conjugate verbs in French, English, Spanish, Italian, Portuguese and Romanian (more soon)\n    using Machine Learning techniques.\n| Any verb in one of the supported language can be conjugated, as the module contains a Machine Learning model of how the verbs behave.\n| Even completely new or made-up verbs can be successfully conjugated in this manner.\n| The supplied pre-trained models are composed of:\n\n- a binary feature extractor,\n- a feature selector using Linear Support Vector Classification,\n- a classifier using Stochastic Gradient Descent.\n\n| MLConjug3 uses scikit-learn to implement the Machine Learning algorithms.\n| Users of the library can use any compatible classifiers from scikit-learn to modify and retrain the models.\n\n| The training data for the french model is based on Verbiste https://perso.b2b2c.ca/~sarrazip/dev/verbiste.html .\n| The training data for English, Spanish, Italian, Portuguese and Romanian was generated using unsupervised learning techniques\n  using the French model as a model to query during the training.\n\n.. warning::\n    MLCONJUG3 now only supports Python 3.x as Python 2.x has been deprecated in 2020.\n\n* Free software: MIT license\n* Documentation: https://sekoudiaonlp.github.io/mlconjug3/index.html.\n\n\nSupported Languages\n-------------------\n\n- French\n- English\n- Spanish\n- Italian\n- Portuguese\n- Romanian\n\n\nFeatures\n--------\n\n- Easy to use API.\n- Includes pre-trained models with 99% + accuracy in predicting conjugation class of unknown verbs.\n- Easily train new models or add new languages.\n- Easily integrate MLConjug in your own projects.\n- Can be used as a command line tool.\n\n\nAcademic publications citing mlconjug\n-------------------------------------\n\n- | Ali Malik and Mike Wu and Vrinda Vasavada and Jinpeng Song and John Mitchell and Noah D. Goodman and Chris Piech.\n  | "`Generative Grading Neural Approximate Parsing for Automated Student Feedback`_".\n  | Proceedings of the 34th AAAI conference on Artificial Intelligence, 2019.\n\nSoftware projects using mlconjug\n--------------------------------\n\n- | `NLP-Suite`_\n  | NLP Suite is a package of tools designed for non-specialists, for scholars with no knowledge or little knowledge of Natural Language Processing.\n- | `Gender Bias Visualization`_\n  | This project offers tools to visualize the gender bias in pre-trained language models to better understand the prejudices in the data.\n- | `Text Adaptation To Context`_\n  | This project uses language models to generate text that is well suited to the type of publication.\n- | `verbecc-svc`_\n  | Dockerized microservice with REST API for conjugation of any verb in French and Spanish.\n- | `nvhtml`_\n  | A tool to Manage and tansform HTML documents.\n- | `twitter-bot`_\n  | Tweets the words of the French language. Largely inspired by the @botducul (identical lexicon, but code in Python) and the @botsupervnr.\n  | Posts on @botduslip. Stores the position of the last tweeted word in a Redis database.\n- | `verb-form-helper`_\n  | This project offers a tool to help learn differnt verbal forms.\n- | `NLP Tasks`_\n  | A collection of common NLP tasks such as dataset parsing and explicit semantic extraction.\n- | `Facemask Detection`_\n  | This project offers a model which recognizes covid-19 masks.\n- | `Bad Excuses for Zoom Abuses`_\n  | Need an excuse for why you can\'t show up in your Zoom lectures? Just generate one here!\n- | `NLP`_\n  | Repository to store Natural Language Processing models.\n- | `Virtual Assistant`_\n  | This is a simple virtual assistant. With it, you can search the Internet, access websites, open programs, and more using just your voice.\n  | This virtual assistant supports the English and Portuguese languages and has many settings that you can adjust to your liking.\n- | `Bad Advice`_\n  | This python module responds to yes or no questions. It dishes out its advice at random.\n  | Disclaimer: Do not actually act on this advice ;)\n- | `Spanish Conjugations Quiz`_\n  | Python+Flask web app that uses mlconjug to dynamically generate foreign language conjugation questions.\n- | `Silver Rogue DF`_\n  | A dwarf-fortress adventure mode-inspired rogue-like Pygame Python3 game.\n\nBibTeX\n------\n\nIf you want to cite mlconjug3 in an academic publication use this citation format:\n\n.. code:: bibtex\n\n   @article{mlconjug3,\n     title={mlconjug3},\n     author={Sekou Diao},\n     journal={GitHub. Note: https://github.com/SekouDiaoNlp/mlconjug3 Cited by},\n     year={2021}\n   }\n\n\nCredits\n-------\n\nThis package was created with the help of Verbiste_ and scikit-learn_.\n\nThe logo was designed by Zuur_.\n\n.. _Verbiste: https://perso.b2b2c.ca/~sarrazip/dev/verbiste.html\n.. _scikit-learn: http://scikit-learn.org/stable/index.html\n.. _Zuur: https://github.com/zuuritaly\n.. _`Generative Grading Neural Approximate Parsing for Automated Student Feedback`: https://arxiv.org/abs/1905.09916\n.. _`Gender Bias Visualization`: https://github.com/GesaJo/Gender-Bias-Visualization\n.. _`Text Adaptation To Context`: https://github.com/lzontar/Text_Adaptation_To_Context\n.. _`Facemask Detection`: https://github.com/samuel-karanja/facemask-derection\n.. _`Bad Excuses for Zoom Abuses`: https://github.com/tyxchen/bad-excuses-for-zoom-abuses\n.. _NLP: https://github.com/pskshyam/NLP\n.. _`Virtual Assistant`: https://github.com/JeanExtreme002/Virtual-Assistant\n.. _`Bad Advice`: https://github.com/matthew-cheney/bad-advice\n.. _`Spanish Conjugations Quiz`: https://github.com/williammortimer/Spanish-Conjugations-Quiz\n.. _`Silver Rogue DF`: https://github.com/FranchuFranchu/silver-rogue-df\n.. _`NLP-Suite`: https://github.com/NLP-Suite/NLP-Suite\n.. _`twitter-bot`: https://github.com/arthurcouyere/twitter-bot\n.. _`verb-form-helper`: https://github.com/gittymutt/verb-form-helper\n.. _`NLP Tasks`: https://github.com/ai-systems/poly-nlp\n.. _`verbecc-svc`: https://pypi.org/project/verbecc/\n.. _`nvhtml`: https://pypi.org/project/nvhtml/\n',
    'author': 'SekouDiaoNlp',
    'author_email': 'diao.sekou.nlp@gmail.com',
    'maintainer': 'SekouDiaoNlp',
    'maintainer_email': 'diao.sekou.nlp@gmail.com',
    'url': 'https://github.com/SekouDiaoNlp/mlconjug3',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7.1,<4',
}


setup(**setup_kwargs)
